package com.zfire.jiasm.syncdata.download.basedata;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.zfire.jiasm.syncdata.constant.DictTypeEnum;
import com.zfire.jiasm.syncdata.constant.InterFaceTypeEnum;
import com.zfire.jiasm.syncdata.data.Token;
import com.zfire.jiasm.syncdata.plus.entity.ItfTblWangdianWxgDownload;
import com.zfire.jiasm.syncdata.plus.entity.Worker;
import com.zfire.jiasm.syncdata.plus.service.ItfTblWangdianWxgDownloadService;
import com.zfire.jiasm.syncdata.plus.service.WorkerService;
import com.zfire.jiasm.syncdata.utils.HttpUtil;
import com.zfire.jiasm.syncdata.utils.JSONResult;
import com.zfire.jiasm.syncdata.utils.MyBeanUtils;
import com.zfire.jiasm.syncdata.utils.TokenCenter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 格力品牌网点维修工基础资料下载
 */
@Slf4j
@Component
public class GLPPGFWebsitWorker {
    @Value("${baseurl}")
    private String baseurl = "";

    @Resource
    TokenCenter tokenCenter;
    @Resource
    ItfTblWangdianWxgDownloadService itfTblWangdianWxgDownloadService;
    @Resource
    WorkerService workerService;



    /**
     * X2300000 佛山销售网点维修工基础资料下载
     * @return
     */
    @Scheduled(fixedDelay = 1 * 60 * 1000)
    @Transactional(rollbackFor = Exception.class)
    public void processFSXSWDTask() throws Exception {
        if (1==1){
            return;
        }
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Map<String, String> paramMap = new HashMap<String, String>();
        List<ItfTblWangdianWxgDownload> addRec = new ArrayList<>();
        List<ItfTblWangdianWxgDownload> updateRec = new ArrayList<>();

        log.info("开始下载佛山销售网点维修工基础资料信息: \uF0B7{}",sdf.format(new Date()));

        Token token = tokenCenter.getCurrentToken();
        String url = baseurl + InterFaceTypeEnum.GLXSSH_WEBSIT_WORK.getCode() + "/querylist";
        paramMap.put("belongCompany", InterFaceTypeEnum.FSXS_WEBSIT_CODE.getCode());
        String paramJson= JSON.toJSONString(paramMap);

        JSONResult jsonResult = HttpUtil.httpRequestWithToken(url, "POST", paramJson, token);
        if (jsonResult.getStatus() == null || !jsonResult.getStatus().toString().equals("200")) {
            log.info("下载佛山销售网点维修工基础资料信息失败！: {}",jsonResult.getMessage());
            return;
        }

        JSONArray jsonArray = (JSONArray) jsonResult.getData();
        if (jsonArray != null) {
            log.info("佛山销售网点维修工下载了{}条数据",jsonArray.size());

            // 数据同步落到同步信息表
            extractedAddOrUpdate(addRec, updateRec, jsonArray);

            // 数据同步到本地表
            extractedLocalAddOrUpdate(addRec, updateRec);


            log.info("佛山销售网点维修工基础资料信息处理完成: \uF0B7{}",sdf.format(new Date()));
        }else {
            log.info("["+url+"]无数据");
        }
    }

    /**
     * X2100000 广州销售网点维修工基础资料下载
     * @return
     */
    @Scheduled(fixedDelay = 1 * 60 * 1000)
    @Transactional(rollbackFor = Exception.class)
    public void processGZXSWDTask() throws Exception {
        if (1==1){
            return;
        }

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Map<String, String> paramMap = new HashMap<String, String>();
        List<ItfTblWangdianWxgDownload> addRec = new ArrayList<>();
        List<ItfTblWangdianWxgDownload> updateRec = new ArrayList<>();

        log.info("开始下载广州销售网点维修工基础资料信息: \uF0B7{}",sdf.format(new Date()));

        Token token = tokenCenter.getCurrentToken();
        String url = baseurl + InterFaceTypeEnum.GLXSSH_WEBSIT_WORK.getCode() + "/querylist";
        paramMap.put("belongCompany", InterFaceTypeEnum.GZXS_WEBSIT_CODE.getCode());
        String paramJson= JSON.toJSONString(paramMap);

        JSONResult jsonResult = HttpUtil.httpRequestWithToken(url, "POST", paramJson, token);
        if (jsonResult.getStatus() == null || !jsonResult.getStatus().toString().equals("200")) {
            log.info("下载广州销售网点维修工基础资料信息失败！: {}",jsonResult.getMessage());
            return;
        }

        JSONArray jsonArray = (JSONArray) jsonResult.getData();
        if (jsonArray != null) {
            log.info("广州销售网点维修工下载了{}条数据",jsonArray.size());

            // 数据同步落到同步信息表
            extractedAddOrUpdate(addRec, updateRec, jsonArray);

            // 数据同步到本地表
            extractedLocalAddOrUpdate(addRec, updateRec);

            log.info("广州销售网点维修工基础资料信息处理完成: \uF0B7{}",sdf.format(new Date()));
        }else {
            log.info("["+url+"]无数据");
        }
    }

    /**
     * S9219807 佛山售后网点维修工基础资料下载
     * @return
     */
    @Scheduled(fixedDelay = 1 * 60 * 1000)
    @Transactional(rollbackFor = Exception.class)
    public void processFSSHWDTask() throws Exception {
        if (1==1){
            return;
        }

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Map<String, String> paramMap = new HashMap<String, String>();
        List<ItfTblWangdianWxgDownload> addRec = new ArrayList<>();
        List<ItfTblWangdianWxgDownload> updateRec = new ArrayList<>();

        log.info("开始下载佛山售后网点维修工基础资料信息: \uF0B7{}",sdf.format(new Date()));

        Token token = tokenCenter.getCurrentToken();
        String url = baseurl + InterFaceTypeEnum.GLXSSH_WEBSIT_WORK.getCode() + "/querylist";
        paramMap.put("belongCompany", InterFaceTypeEnum.FSSH_WEBSIT_CODE.getCode());
        String paramJson= JSON.toJSONString(paramMap);

        JSONResult jsonResult = HttpUtil.httpRequestWithToken(url, "POST", paramJson, token);
        if (jsonResult.getStatus() == null || !jsonResult.getStatus().toString().equals("200")) {
            log.info("下载佛山售后网点维修工基础资料信息失败！: {}",jsonResult.getMessage());
            return;
        }

        JSONArray jsonArray = (JSONArray) jsonResult.getData();
        if (jsonArray != null) {
            log.info("佛山售后网点维修工下载了{}条数据",jsonArray.size());

            // 数据同步落到同步信息表
            extractedAddOrUpdate(addRec, updateRec, jsonArray);

            // 数据同步到本地表
            extractedLocalAddOrUpdate(addRec, updateRec);

            log.info("佛山售后网点维修工基础资料信息处理完成: \uF0B7{}",sdf.format(new Date()));
        }else {
            log.info("["+url+"]无数据");
        }
    }

    /**
     * S9219801 广州售后网点维修工基础资料下载
     * @return
     */
    @Scheduled(fixedDelay = 1 * 60 * 1000)
    @Transactional(rollbackFor = Exception.class)
    public void processGZSHWDTask() throws Exception {
        if (1==1){
            return;
        }

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Map<String, String> paramMap = new HashMap<String, String>();
        List<ItfTblWangdianWxgDownload> addRec = new ArrayList<>();
        List<ItfTblWangdianWxgDownload> updateRec = new ArrayList<>();

        log.info("开始下载广州售后网点维修工基础资料信息: \uF0B7{}",sdf.format(new Date()));

        Token token = tokenCenter.getCurrentToken();
        String url = baseurl + InterFaceTypeEnum.GLXSSH_WEBSIT_WORK.getCode() + "/querylist";
        paramMap.put("belongCompany", InterFaceTypeEnum.GSSH_WEBSIT_CODE.getCode());
        String paramJson= JSON.toJSONString(paramMap);

        JSONResult jsonResult = HttpUtil.httpRequestWithToken(url, "POST", paramJson, token);
        if (jsonResult.getStatus() == null || !jsonResult.getStatus().toString().equals("200")) {
            log.info("下载广州售后网点维修工基础资料信息失败！: {}",jsonResult.getMessage());
            return;
        }

        JSONArray jsonArray = (JSONArray) jsonResult.getData();
        if (jsonArray != null) {
            log.info("广州售后网点维修工下载了{}条数据",jsonArray.size());

            // 数据同步落到同步信息表
            extractedAddOrUpdate(addRec, updateRec, jsonArray);

            // 数据同步到本地表
            extractedLocalAddOrUpdate(addRec, updateRec);

            log.info("广州售后网点维修工基础资料信息处理完成: \uF0B7{}",sdf.format(new Date()));
        }else {
            log.info("["+url+"]无数据");
        }
    }

    private void extractedLocalAddOrUpdate(List<ItfTblWangdianWxgDownload> addRec, List<ItfTblWangdianWxgDownload> updateRec) {
        List<Worker> addWorkerRec = new ArrayList<>();
        List<Worker> updateWorkerRec = new ArrayList<>();

        // 获取新增的
        if (addRec.size()>0){
            extractedWorkerAddNew(addRec, addWorkerRec);
        }

        // 获取修改的   取消修改
        /*if (updateRec.size()>0){
            extractedWorkerUpdateNew(updateRec, updateWorkerRec);
        }*/

        // 新增的插入到表
        if (addWorkerRec.size()>0){
            workerService.saveBatch(addWorkerRec);
            log.info("本地网点维修工人员信息表新增插入了{}条数据", addWorkerRec.size());
        }
        // 更新
        if (updateWorkerRec.size()>0){
            workerService.updateBatchById(updateWorkerRec);
            log.info("本地网点维修工人员信息表更新修改了{}条数据", updateWorkerRec.size());
        }
    }

    private void extractedWorkerUpdateNew(List<ItfTblWangdianWxgDownload> updateRec, List<Worker> updateWorkerRec) {
        Boolean flag;
        // 提取原有的信息
        List<Worker> oldWorkerRec =  workerService.lambdaQuery().list();
        Map<String, List<Worker>> oldRecMap = oldWorkerRec.stream().collect(Collectors.groupingBy(Worker::getWorkerId));

        for (ItfTblWangdianWxgDownload m : updateRec){
            flag = Boolean.FALSE;
            Worker o = oldRecMap.get(String.valueOf(m.getSfzen())).get(0);
            // 网点编号不相同不修改
            if (!o.getWebsitNumber().equals(m.getWdno())){
                continue;
            }
            getUpdateInfo(updateWorkerRec, flag, m, o);
        }
    }



    // 备份不用
    private void extractedWorkerUpdate(List<ItfTblWangdianWxgDownload> updateRec, List<Worker> updateWorkerRec) {
        Boolean flag;
        // 提取原有的信息
        List<Worker> oldWorkerRec =  workerService.lambdaQuery().list();
        Map<String, List<Worker>> oldRecMap = oldWorkerRec.stream().collect(Collectors.groupingBy(Worker::getWorkerId));

        for (ItfTblWangdianWxgDownload m : updateRec){
            flag = Boolean.FALSE;
            Worker o = oldRecMap.get(String.valueOf(m.getSfzen())).get(0);
            Worker v = new Worker();
            v.setWorkerId(o.getWorkerId());

            v.setUpdateBy("system");
            v.setUpdateTime(new Date());
            if (m.getLastModifiedBy() != null){
                v.setUpdateBy(m.getLastModifiedBy());
            }
            if (m.getLastModifiedDate() != null){
                v.setUpdateTime(m.getLastModifiedDate());
            }

            if (!o.getWorkerName().equals(m.getWxgmc())){
                v.setWorkerName(m.getWxgmc());
                flag = Boolean.TRUE;
            }
            if (!o.getGender().equals(m.getXingb())){
                v.setGender(m.getXingb());
                flag = Boolean.TRUE;
            }
            if (m.getSfzen() !=null && !o.getIdcard().equals(m.getSfzen())){
                v.setIdcard(m.getSfzen());
                flag = Boolean.TRUE;
            }
            if (m.getXueli() !=null && !o.getEducation().equals(m.getXueli())){
                v.setEducation(m.getXueli());
                flag = Boolean.TRUE;
            }
            if (!o.getAge().equals(m.getNianl())){
                v.setAge(m.getNianl());
                flag = Boolean.TRUE;
            }
            if (m.getYddh() !=null && !o.getMobile().equals(m.getYddh())){
                v.setMobile(m.getYddh());
                flag = Boolean.TRUE;
            }
            if (m.getXcsgz() !=null && !o.getJob().equals(m.getXcsgz())){
                v.setJob(m.getXcsgz());
                flag = Boolean.TRUE;
            }
            if (!o.getJobAge().equals(m.getCsgzns())){
                v.setJobAge(m.getCsgzns());
                flag = Boolean.TRUE;
            }
            if (m.getZgzh() !=null && !o.getNvq().equals(m.getZgzh())){
                v.setNvq(m.getZgzh());
                flag = Boolean.TRUE;
            }
            if (m.getWdno() !=null && !o.getWebsitNumber().equals(m.getWdno())){
                v.setWebsitNumber(m.getWdno());
                flag = Boolean.TRUE;
            }
            if (m.getGmbxdh() !=null && !o.getSafeNo().equals(m.getGmbxdh())){
                v.setSafeNo(m.getGmbxdh());
                flag = Boolean.TRUE;
            }
            if (m.getPxqk() !=null && !o.getTrain().equals(m.getPxqk())){
                v.setTrain(m.getPxqk());
                flag = Boolean.TRUE;
            }
            if (m.getJsdj() !=null && !o.getSkillLevel().equals(m.getJsdj())){
                v.setSkillLevel(m.getJsdj());
                flag = Boolean.TRUE;
            }
            if (m.getBeiz() !=null && !o.getRemark().equals(m.getBeiz())){
                v.setRemark(m.getBeiz());
                flag = Boolean.TRUE;
            }
            if (m.getFlag().trim().equals(DictTypeEnum.DICT_TYPE_ON.getText())) {
                if (!o.getStatus().equals(DictTypeEnum.DICT_TYPE_ON.getCode())){
                    v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
                    flag = Boolean.TRUE;
                }
            } else {
                if (!o.getStatus().equals(DictTypeEnum.DICT_TYPE_OFF.getCode())){
                    v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
                    flag = Boolean.TRUE;
                }
            }
            if (m.getUsid() !=null && !o.getAdminUserId().equals(m.getUsid())){
                v.setAdminUserId(m.getUsid());
                flag = Boolean.TRUE;
            }
            if (m.getIfmessage().trim().equals(DictTypeEnum.RECEIVE_TYPE_YES.getText())) {
                if (!o.getIsSmsNotice().equals(DictTypeEnum.RECEIVE_TYPE_YES.getCode())){
                    v.setIsSmsNotice(DictTypeEnum.RECEIVE_TYPE_YES.getCode());
                    flag = Boolean.TRUE;
                }
            } else {
                if (!o.getIsSmsNotice().equals(DictTypeEnum.RECEIVE_TYPE_NO.getCode())){
                    v.setIsSmsNotice(DictTypeEnum.RECEIVE_TYPE_NO.getCode());
                    flag = Boolean.TRUE;
                }
            }
            if (m.getSfzst().trim().equals(DictTypeEnum.ZST_TYPE_YES.getText())) {
                if (!o.getIsZst().equals(DictTypeEnum.ZST_TYPE_YES.getCode())){
                    v.setIsZst(DictTypeEnum.ZST_TYPE_YES.getCode());
                    flag = Boolean.TRUE;
                }
            } else {
                if (!o.getIsZst().equals(DictTypeEnum.ZST_TYPE_NO.getCode())){
                    v.setIsZst(DictTypeEnum.ZST_TYPE_NO.getCode());
                    flag = Boolean.TRUE;
                }
            }
            if (m.getShyj() !=null && !o.getZstExamineRemark().equals(m.getShyj())){
                v.setZstExamineRemark(m.getShyj());
                flag = Boolean.TRUE;
            }
            if (m.getZstsj() !=null && !o.getZstTime().equals(m.getZstsj())){
                v.setZstTime(m.getZstsj());
                flag = Boolean.TRUE;
            }

            if (m.getSfhmd().trim().equals(DictTypeEnum.HMD_TYPE_YES.getText())) {
                if (!o.getIsBlackList().equals(DictTypeEnum.HMD_TYPE_YES.getCode())){
                    v.setIsBlackList(DictTypeEnum.HMD_TYPE_YES.getCode());
                    flag = Boolean.TRUE;
                }
            } else {
                if (!o.getIsBlackList().equals(DictTypeEnum.HMD_TYPE_NO.getCode())){
                    v.setIsBlackList(DictTypeEnum.HMD_TYPE_NO.getCode());
                    flag = Boolean.TRUE;
                }
            }
            if (m.getGmbxgs() !=null && !o.getSafeCompany().equals(m.getGmbxgs())){
                v.setSafeCompany(m.getGmbxgs());
                flag = Boolean.TRUE;
            }
            if (m.getGmbxyxq() !=null && !o.getGmbxyxq().equals(m.getGmbxyxq())){
                v.setGmbxyxq(m.getGmbxyxq());
                flag = Boolean.TRUE;
            }
            if (m.getHmdbz() !=null && !o.getBlackListRemark().equals(m.getHmdbz())){
                v.setBlackListRemark(m.getHmdbz());
                flag = Boolean.TRUE;
            }
            if (m.getSfpxhg()>0){
                if (!o.getTrainStatus()){
                    v.setTrainStatus(Boolean.TRUE);
                    flag = Boolean.TRUE;
                }
            } else {
                if (o.getTrainStatus()){
                    v.setTrainStatus(Boolean.FALSE);
                    flag = Boolean.TRUE;
                }
            }
            if (!o.getNewOldFlag().equals(m.getXjflag())){
                v.setNewOldFlag(m.getXjflag());
                flag = Boolean.TRUE;
            }
            if (!o.getCollectNum().equals(m.getMrcjgdl())){
                v.setCollectNum(m.getMrcjgdl());
                flag = Boolean.TRUE;
            }
            if (!o.getCollectEnginNum().equals(m.getMrcjgcjgdl())){
                v.setCollectEnginNum(m.getMrcjgcjgdl());
                flag = Boolean.TRUE;
            }
            if (!o.getCollectLimitNum().equals(m.getYxcjgdl())){
                v.setCollectLimitNum(m.getYxcjgdl());
                flag = Boolean.TRUE;
            }
            if (!o.getCollectEnginLimitNum().equals(m.getYxcjgcjgdl())){
                v.setCollectEnginLimitNum(m.getYxcjgcjgdl());
                flag = Boolean.TRUE;
            }
            if (m.getMrdate() !=null && !o.getMrdate().equals(m.getMrdate())){
                v.setMrdate(m.getMrdate());
                flag = Boolean.TRUE;
            }
            if (m.getXsgsshren() !=null && !o.getSaleExamineBy().equals(m.getXsgsshren())){
                v.setSaleExamineBy(m.getXsgsshren());
                flag = Boolean.TRUE;
            }
            if (m.getXsgsshsj() !=null && !o.getSaleExamineTime().equals(m.getXsgsshsj())){
                v.setSaleExamineTime(m.getXsgsshsj());
                flag = Boolean.TRUE;
            }
            if (!o.getSaleExamineStatus().equals(m.getXsgsshstat())){
                v.setSaleExamineStatus(m.getXsgsshstat());
                flag = Boolean.TRUE;
            }
            if (m.getXsgsshbeiz() !=null && !o.getSaleExamineRemark().equals(m.getXsgsshbeiz())){
                v.setSaleExamineRemark(m.getXsgsshbeiz());
                flag = Boolean.TRUE;
            }
            if (m.getZstshren() !=null && !o.getSaleZstExamineBy().equals(m.getZstshren())){
                v.setSaleZstExamineBy(m.getZstshren());
                flag = Boolean.TRUE;
            }
            if (!o.getScore().equals(m.getWxfensu())){
                v.setScore(m.getWxfensu());
                flag = Boolean.TRUE;
            }
            if (m.getYddhold() !=null && !o.getOldMobile().equals(m.getYddhold())){
                v.setOldMobile(m.getYddhold());
                flag = Boolean.TRUE;
            }
            if (!o.getHasFace().equals(m.getHasface())){
                v.setHasFace(m.getHasface());
                flag = Boolean.TRUE;
            }
            if (m.getFacepath() !=null && !o.getFacePath().equals(m.getFacepath())){
                v.setFacePath(m.getFacepath());
                flag = Boolean.TRUE;
            }
            if (!o.getFaceCheck().equals(m.getFacecheck())){
                v.setFaceCheck(m.getFacecheck());
                flag = Boolean.TRUE;
            }
            if (m.getCphm() !=null && !o.getCarNo().equals(m.getCphm())){
                v.setCarNo(m.getCphm());
                flag = Boolean.TRUE;
            }
            if (m.getGpsid() !=null && !o.getGpsMachineId().equals(m.getGpsid())){
                v.setGpsMachineId(m.getGpsid());
                flag = Boolean.TRUE;
            }
            if (m.getVipflag() !=null && !o.getVipFlag().equals(m.getVipflag())){
                v.setVipFlag(m.getVipflag());
                flag = Boolean.TRUE;
            }
            if (flag){
                updateWorkerRec.add(v);
            }
        }
    }

    private void extractedWorkerAddNew(List<ItfTblWangdianWxgDownload> addRec, List<Worker> addWorkerRec) {
        // 提取原有的信息
        List<Worker> oldWorkerRec =  workerService.lambdaQuery()
                .select(Worker::getWorkerId).list();
        Map<String, List<Worker>> oldRecMap = oldWorkerRec.stream().collect(Collectors.groupingBy(Worker::getWorkerId));
        List<String> sfzens = new ArrayList<>();

        for (ItfTblWangdianWxgDownload m : addRec){
            // 已存在不再添加
            if (oldRecMap.containsKey(m.getSfzen()) || sfzens.contains(m.getSfzen())){
                continue;
            }

            // 无效的数据不新增
            if (m.getFlag() != null){
                if (!m.getFlag().trim().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
                    continue;
                }
            }

            // 生成对象
            getWorker(addWorkerRec, sfzens, m);

            // 新增的插入到表
            if (addWorkerRec.size()>=3000){
                workerService.saveBatch(addWorkerRec);
                log.info("本地网点维修工人员信息表新增插入了{}条数据", addWorkerRec.size());
                addWorkerRec.clear();
            }
        }
    }

    private void getWorker(List<Worker> addWorkerRec, List<String> sfzens, ItfTblWangdianWxgDownload m) {
        Worker v = new Worker();
         v.setSyncFlag(1);
        v.setWorkerId(String.valueOf(m.getSfzen()));
        //v.setIsReal("YES");
        // v.setFddReal("NO");
        // v.setFddSerialNo();
        // v.setIsApplyOver("NO");
        v.setCreateBy("system");
        v.setUpdateBy("system");
        v.setCreateTime(new Date());
        v.setUpdateTime(new Date());
            /*if (m.getCreatedBy() != null){
                v.setCreateBy(m.getCreatedBy());
            }
            if (m.getCreatedDate() != null){
                v.setCreateTime(m.getCreatedDate());
            }
            if (m.getLastModifiedBy() != null){
                v.setUpdateBy(m.getLastModifiedBy());
            }
            if (m.getLastModifiedDate() != null){
                v.setUpdateTime(m.getLastModifiedDate());
            }*/
        v.setWorkerName(m.getWxgmc());
        // v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
            /*if (m.getFlag() != null){
                if (!m.getFlag().trim().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
                    v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
                }
            }*/

        // 工程师类型
        // v.setWorkerType();
        // v.setBirthDate();
        v.setGender(m.getXingb());
        v.setMobile(m.getYddh());
        v.setIdcard(m.getSfzen());
        v.setAge(m.getNianl());
        // v.setNameLevel();
        // v.setIntegralLevel();
        // v.setUserNameLevel();
        // v.setIntegralFree()
        v.setEducation(m.getXueli());




        // v.setAddress();
        /*v.setIsSmsNotice(DictTypeEnum.RECEIVE_TYPE_NO.getCode());
        if (m.getIfmessage() != null){
            if (!m.getIfmessage().trim().equals(DictTypeEnum.RECEIVE_TYPE_YES.getText())){
                v.setIsSmsNotice(DictTypeEnum.RECEIVE_TYPE_YES.getCode());
            }
        }
        v.setIsBlackList(DictTypeEnum.HMD_TYPE_NO.getCode());
        if (m.getSfhmd() != null){
            if (!m.getSfhmd().trim().equals(DictTypeEnum.HMD_TYPE_YES.getText())){
                v.setIsBlackList(DictTypeEnum.HMD_TYPE_YES.getCode());
            }
        }
        v.setBlackListRemark(m.getHmdbz());
        v.setExamineStatus(v.getStatus());*/

        v.setNvq(m.getZgzh());
        // v.setWebsitNumber(m.getWdno());
        v.setSafeNo(m.getGmbxdh());
        // v.setTrain(m.getPxqk());
        v.setSkillLevel(m.getJsdj());
        v.setRemark(m.getBeiz());

        // 不能用
        // v.setAdminUserId(m.getUsid());

        v.setIsZst(DictTypeEnum.ZST_TYPE_NO.getCode());
        if (m.getSfzst() != null){
            if (!m.getSfzst().trim().equals(DictTypeEnum.ZST_TYPE_YES.getText())){
                v.setIsZst(DictTypeEnum.ZST_TYPE_YES.getCode());
            }
        }
        v.setZstExamineRemark(m.getShyj());
        v.setZstTime(m.getZstsj());

        v.setSafeCompany(m.getGmbxgs());
        v.setGmbxyxq(m.getGmbxyxq());

        v.setTrainStatus(Boolean.FALSE);
        if (m.getSfpxhg()>0){
            v.setTrainStatus(Boolean.TRUE);
        }
        v.setNewOldFlag(m.getXjflag());
        v.setCollectNum(m.getMrcjgdl());
        v.setCollectEnginNum(m.getMrcjgcjgdl());
        v.setCollectLimitNum(m.getYxcjgdl());
        v.setCollectEnginLimitNum(m.getYxcjgcjgdl());
        v.setMrdate(m.getMrdate());
        v.setSaleExamineBy(m.getXsgsshren());
        v.setSaleExamineTime(m.getXsgsshsj());
        v.setSaleExamineStatus(m.getXsgsshstat());
        v.setSaleExamineRemark(m.getXsgsshbeiz());
        v.setSaleZstExamineBy(m.getZstshren());
        v.setScore(m.getWxfensu());
        v.setOldMobile(m.getYddhold());
 /*       v.setHasFace(m.getHasface());
        v.setFacePath(m.getFacepath());
        v.setFaceCheck(m.getFacecheck());*/
        v.setCarNo(m.getCphm());
        v.setGpsMachineId(m.getGpsid());
        v.setVipFlag(m.getVipflag());



        addWorkerRec.add(v);
        sfzens.add(m.getSfzen());
    }

    private void getUpdateInfo(List<Worker> updateWorkerRec, Boolean flag, ItfTblWangdianWxgDownload m, Worker o) {
        Worker v = new Worker();
        v.setWorkerId(o.getWorkerId());


        v.setUpdateBy("system");
        v.setUpdateTime(new Date());
        if (m.getLastModifiedBy() != null){
            v.setUpdateBy(m.getLastModifiedBy());
        }
        if (m.getLastModifiedDate() != null){
            v.setUpdateTime(m.getLastModifiedDate());
        }

        if (!o.getWorkerName().equals(m.getWxgmc())){
            v.setWorkerName(m.getWxgmc());
            flag = Boolean.TRUE;
        }
        if (!o.getGender().equals(m.getXingb())){
            v.setGender(m.getXingb());
            flag = Boolean.TRUE;
        }
        if (m.getSfzen() !=null && !o.getIdcard().equals(m.getSfzen())){
            v.setIdcard(m.getSfzen());
            flag = Boolean.TRUE;
        }
        if (m.getXueli() !=null && !o.getEducation().equals(m.getXueli())){
            v.setEducation(m.getXueli());
            flag = Boolean.TRUE;
        }
        if (!o.getAge().equals(m.getNianl())){
            v.setAge(m.getNianl());
            flag = Boolean.TRUE;
        }
        if (m.getYddh() !=null && !o.getMobile().equals(m.getYddh())){
            v.setMobile(m.getYddh());
            flag = Boolean.TRUE;
        }

        if (m.getZgzh() !=null && !o.getNvq().equals(m.getZgzh())){
            v.setNvq(m.getZgzh());
            flag = Boolean.TRUE;
        }
        if (m.getGmbxdh() !=null && !o.getSafeNo().equals(m.getGmbxdh())){
            v.setSafeNo(m.getGmbxdh());
            flag = Boolean.TRUE;
        }

        if (m.getJsdj() !=null && !o.getSkillLevel().equals(m.getJsdj())){
            v.setSkillLevel(m.getJsdj());
            flag = Boolean.TRUE;
        }
        if (m.getBeiz() !=null && !o.getRemark().equals(m.getBeiz())){
            v.setRemark(m.getBeiz());
            flag = Boolean.TRUE;
        }

        if (m.getSfzst().trim().equals(DictTypeEnum.ZST_TYPE_YES.getText())) {
            if (!o.getIsZst().equals(DictTypeEnum.ZST_TYPE_YES.getCode())){
                v.setIsZst(DictTypeEnum.ZST_TYPE_YES.getCode());
                flag = Boolean.TRUE;
            }
        } else {
            if (!o.getIsZst().equals(DictTypeEnum.ZST_TYPE_NO.getCode())){
                v.setIsZst(DictTypeEnum.ZST_TYPE_NO.getCode());
                flag = Boolean.TRUE;
            }
        }
        if (m.getShyj() !=null && !o.getZstExamineRemark().equals(m.getShyj())){
            v.setZstExamineRemark(m.getShyj());
            flag = Boolean.TRUE;
        }
        if (m.getZstsj() !=null && !o.getZstTime().equals(m.getZstsj())){
            v.setZstTime(m.getZstsj());
            flag = Boolean.TRUE;
        }
        if (m.getSfhmd().trim().equals(DictTypeEnum.HMD_TYPE_YES.getText())) {
            if (!o.getIsBlackList().equals(DictTypeEnum.HMD_TYPE_YES.getCode())){
                v.setIsBlackList(DictTypeEnum.HMD_TYPE_YES.getCode());
                flag = Boolean.TRUE;
            }
        } else {
            if (!o.getIsBlackList().equals(DictTypeEnum.HMD_TYPE_NO.getCode())){
                v.setIsBlackList(DictTypeEnum.HMD_TYPE_NO.getCode());
                flag = Boolean.TRUE;
            }
        }
        if (m.getGmbxgs() !=null && !o.getSafeCompany().equals(m.getGmbxgs())){
            v.setSafeCompany(m.getGmbxgs());
            flag = Boolean.TRUE;
        }
        if (m.getGmbxyxq() !=null && !o.getGmbxyxq().equals(m.getGmbxyxq())){
            v.setGmbxyxq(m.getGmbxyxq());
            flag = Boolean.TRUE;
        }
        if (m.getHmdbz() !=null && !o.getBlackListRemark().equals(m.getHmdbz())){
            v.setBlackListRemark(m.getHmdbz());
            flag = Boolean.TRUE;
        }
        if (m.getSfpxhg()>0){
            if (!o.getTrainStatus()){
                v.setTrainStatus(Boolean.TRUE);
                flag = Boolean.TRUE;
            }
        } else {
            if (o.getTrainStatus()){
                v.setTrainStatus(Boolean.FALSE);
                flag = Boolean.TRUE;
            }
        }
        if (!o.getNewOldFlag().equals(m.getXjflag())){
            v.setNewOldFlag(m.getXjflag());
            flag = Boolean.TRUE;
        }
        if (!o.getCollectNum().equals(m.getMrcjgdl())){
            v.setCollectNum(m.getMrcjgdl());
            flag = Boolean.TRUE;
        }
        if (!o.getCollectEnginNum().equals(m.getMrcjgcjgdl())){
            v.setCollectEnginNum(m.getMrcjgcjgdl());
            flag = Boolean.TRUE;
        }
        if (!o.getCollectLimitNum().equals(m.getYxcjgdl())){
            v.setCollectLimitNum(m.getYxcjgdl());
            flag = Boolean.TRUE;
        }
        if (!o.getCollectEnginLimitNum().equals(m.getYxcjgcjgdl())){
            v.setCollectEnginLimitNum(m.getYxcjgcjgdl());
            flag = Boolean.TRUE;
        }
        if (m.getMrdate() !=null && !o.getMrdate().equals(m.getMrdate())){
            v.setMrdate(m.getMrdate());
            flag = Boolean.TRUE;
        }
        if (m.getXsgsshren() !=null && !o.getSaleExamineBy().equals(m.getXsgsshren())){
            v.setSaleExamineBy(m.getXsgsshren());
            flag = Boolean.TRUE;
        }
        if (m.getXsgsshsj() !=null && !o.getSaleExamineTime().equals(m.getXsgsshsj())){
            v.setSaleExamineTime(m.getXsgsshsj());
            flag = Boolean.TRUE;
        }
        if (!o.getSaleExamineStatus().equals(m.getXsgsshstat())){
            v.setSaleExamineStatus(m.getXsgsshstat());
            flag = Boolean.TRUE;
        }
        if (m.getXsgsshbeiz() !=null && !o.getSaleExamineRemark().equals(m.getXsgsshbeiz())){
            v.setSaleExamineRemark(m.getXsgsshbeiz());
            flag = Boolean.TRUE;
        }
        if (m.getZstshren() !=null && !o.getSaleZstExamineBy().equals(m.getZstshren())){
            v.setSaleZstExamineBy(m.getZstshren());
            flag = Boolean.TRUE;
        }
        if (!o.getScore().equals(m.getWxfensu())){
            v.setScore(m.getWxfensu());
            flag = Boolean.TRUE;
        }
        if (m.getYddhold() !=null && !o.getOldMobile().equals(m.getYddhold())){
            v.setOldMobile(m.getYddhold());
            flag = Boolean.TRUE;
        }
        if (!o.getHasFace().equals(m.getHasface())){
            v.setHasFace(m.getHasface());
            flag = Boolean.TRUE;
        }
        if (m.getFacepath() !=null && !o.getFacePath().equals(m.getFacepath())){
            v.setFacePath(m.getFacepath());
            flag = Boolean.TRUE;
        }
        if (!o.getFaceCheck().equals(m.getFacecheck())){
            v.setFaceCheck(m.getFacecheck());
            flag = Boolean.TRUE;
        }
        if (m.getCphm() !=null && !o.getCarNo().equals(m.getCphm())){
            v.setCarNo(m.getCphm());
            flag = Boolean.TRUE;
        }
        if (m.getGpsid() !=null && !o.getGpsMachineId().equals(m.getGpsid())){
            v.setGpsMachineId(m.getGpsid());
            flag = Boolean.TRUE;
        }
        if (m.getVipflag() !=null && !o.getVipFlag().equals(m.getVipflag())){
            v.setVipFlag(m.getVipflag());
            flag = Boolean.TRUE;
        }
        if (flag){
            updateWorkerRec.add(v);
        }
    }

    // 备份不用
    private void extractedWorkerAdd(List<ItfTblWangdianWxgDownload> addRec, List<Worker> addWorkerRec) {
        for (ItfTblWangdianWxgDownload m : addRec){
            Worker v = new Worker();
            v.setWorkerId(String.valueOf(m.getWxgid()));
            /*if (StringUtils.isNotEmpty(m.getWxgno())){
                v.setWorkerNo(m.getWxgno());
            }*/
            v.setCreateBy("system");
            v.setUpdateBy("system");
            v.setCreateTime(new Date());
            v.setUpdateTime(new Date());
            if (m.getCreatedBy() != null){
                v.setCreateBy(m.getCreatedBy());
            }
            if (m.getCreatedDate() != null){
                v.setCreateTime(m.getCreatedDate());
            }
            if (m.getLastModifiedBy() != null){
                v.setUpdateBy(m.getLastModifiedBy());
            }
            if (m.getLastModifiedDate() != null){
                v.setUpdateTime(m.getLastModifiedDate());
            }
            v.setWorkerName(m.getWxgmc());
            v.setGender(m.getXingb());
            v.setIdcard(m.getSfzen());
            v.setEducation(m.getXueli());
            v.setAge(m.getNianl());
            v.setMobile(m.getYddh());
            v.setJob(m.getXcsgz());
            v.setJobAge(m.getCsgzns());
            v.setNvq(m.getZgzh());
            v.setWebsitNumber(m.getWdno());
            v.setSafeNo(m.getGmbxdh());
            v.setTrain(m.getPxqk());
            v.setSkillLevel(m.getJsdj());
            v.setRemark(m.getBeiz());
            v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
            if (m.getFlag() != null){
                if (!m.getFlag().trim().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
                    v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
                }
            }
            v.setAdminUserId(m.getUsid());
            v.setIsSmsNotice(DictTypeEnum.RECEIVE_TYPE_NO.getCode());
            if (m.getIfmessage() != null){
                if (!m.getIfmessage().trim().equals(DictTypeEnum.RECEIVE_TYPE_YES.getText())){
                    v.setIsSmsNotice(DictTypeEnum.RECEIVE_TYPE_YES.getCode());
                }
            }
            v.setIsZst(DictTypeEnum.ZST_TYPE_NO.getCode());
            if (m.getSfzst() != null){
                if (!m.getSfzst().trim().equals(DictTypeEnum.ZST_TYPE_YES.getText())){
                    v.setIsZst(DictTypeEnum.ZST_TYPE_YES.getCode());
                }
            }
            v.setZstExamineRemark(m.getShyj());
            v.setZstTime(m.getZstsj());
            // HMD_TYPE_YES
            v.setIsBlackList(DictTypeEnum.HMD_TYPE_NO.getCode());
            if (m.getSfhmd() != null){
                if (!m.getSfhmd().trim().equals(DictTypeEnum.HMD_TYPE_YES.getText())){
                    v.setIsBlackList(DictTypeEnum.HMD_TYPE_YES.getCode());
                }
            }
            v.setSafeCompany(m.getGmbxgs());
            v.setGmbxyxq(m.getGmbxyxq());
            v.setBlackListRemark(m.getHmdbz());
            v.setTrainStatus(Boolean.FALSE);
            if (m.getSfpxhg()>0){
                v.setTrainStatus(Boolean.TRUE);
            }
            v.setNewOldFlag(m.getXjflag());
            v.setCollectNum(m.getMrcjgdl());
            v.setCollectEnginNum(m.getMrcjgcjgdl());
            v.setCollectLimitNum(m.getYxcjgdl());
            v.setCollectEnginLimitNum(m.getYxcjgcjgdl());
            v.setMrdate(m.getMrdate());
            v.setSaleExamineBy(m.getXsgsshren());
            v.setSaleExamineTime(m.getXsgsshsj());
            v.setSaleExamineStatus(m.getXsgsshstat());
            v.setSaleExamineRemark(m.getXsgsshbeiz());
            v.setSaleZstExamineBy(m.getZstshren());
            v.setScore(m.getWxfensu());
            v.setOldMobile(m.getYddhold());
            v.setHasFace(m.getHasface());
            v.setFacePath(m.getFacepath());
            v.setFaceCheck(m.getFacecheck());
            v.setCarNo(m.getCphm());
            v.setGpsMachineId(m.getGpsid());
            v.setVipFlag(m.getVipflag());
            addWorkerRec.add(v);

            // 新增的插入到表
            if (addWorkerRec.size()>=3000){
                workerService.saveBatch(addWorkerRec);
                log.info("本地网点维修工人员信息表新增插入了{}条数据", addWorkerRec.size());
                addWorkerRec.clear();
            }
        }
    }

    private void extractedAddOrUpdate(List<ItfTblWangdianWxgDownload> addRec, List<ItfTblWangdianWxgDownload> updateRec, JSONArray jsonArray) {
        String synTaskNo = UUID.randomUUID().toString();
        List<ItfTblWangdianWxgDownload> add = new ArrayList<>();
        List<ItfTblWangdianWxgDownload> update = new ArrayList<>();
        // 提取现有的数据信息
        List<ItfTblWangdianWxgDownload> oldRec =  itfTblWangdianWxgDownloadService.lambdaQuery().list();
        List<Long> oldRecWxgId = oldRec.stream().map(ItfTblWangdianWxgDownload::getWxgid).collect(Collectors.toList());
        Map<Long, List<ItfTblWangdianWxgDownload>> oldRecMap = oldRec.stream().collect(Collectors.groupingBy(ItfTblWangdianWxgDownload::getWxgid));


        for (int i = 0; i < jsonArray.size(); i++) {
            JSONObject aData = jsonArray.getJSONObject(i);
            ItfTblWangdianWxgDownload item = JSON.toJavaObject(aData,ItfTblWangdianWxgDownload.class);
            // 新增或修改数据
            // 修改
            if (oldRecWxgId.contains(item.getWxgid())){
                ItfTblWangdianWxgDownload old = oldRecMap.get(item.getWxgid()).get(0);
                MyBeanUtils.copyProperties(item,old);
                update.add(old);
                if (update.size()>3000){
                    itfTblWangdianWxgDownloadService.updateBatchById(update);
                    log.info("网点维修工基础资料信息同步更新修改了{}条数据", update.size());
                    updateRec.addAll(update);
                    update.clear();
                }
            } else {
                // 新增
                item.setSynTaskNo(synTaskNo);
                item.setSynReqTime(new Date());
                item.setSynStatus(1);
                item.setSynTime(new Date());
                item.setSynTimes(0);
                add.add(item);

                if (add.size()>=3000){
                    itfTblWangdianWxgDownloadService.saveBatch(add);
                    log.info("网点维修工基础资料信息同步新增插入了{}条数据", add.size());
                    addRec.addAll(add);
                    add.clear();
                }
            }
        }

        // 新增的插入到表
        if (add.size()>0){
            itfTblWangdianWxgDownloadService.saveBatch(add);
            log.info("网点维修工基础资料信息同步新增插入了{}条数据", add.size());
            addRec.addAll(add);
            add.clear();
        }
        // 更新
        if (update.size()>0){
            itfTblWangdianWxgDownloadService.updateBatchById(update);
            log.info("网点维修工基础资料信息同步更新修改了{}条数据", update.size());
            updateRec.addAll(update);
            update.clear();
        }
    }


}
